@@ -1,2 +1,2 @@
 from .handler_decorator import handler_decorator
-from .aws_client.aws_client import AWSClient
\ No newline at end of file
+from .aws_client import AWSClient
\ No newline at end of file
