@@ -5,10 +5,9 @@ from aws_xray_sdk.core import xray_recorder
 from aws_xray_sdk.core import patch_all
 from .aws_client import AWSClient
 
-
 # Initialize sentry, logger and AWS X-Ray
 def handler_decorator(handler):
-  def wrapper(event, context, aws_client: AWSClient):
+  def wrapper(*args, **kwargs):
     
     # Logger
     logger = logging.getLogger()
@@ -17,9 +16,8 @@ def handler_decorator(handler):
     # AWS X-Ray patch all traces 
     patch_all()
 
-    # Define AWS Client
-    aws_client_class = AWSClient()
-    aws_client = aws_client_class.getAWSClient()
+    # Initialize AWS Client
+    AWSClient()
 
     # Sentry
     sentry_sdk.init(
@@ -27,7 +25,7 @@ def handler_decorator(handler):
       traces_sample_rate=1.0
     )
     try:
-      return handler(event, context, aws_client)
+      return handler(*args, **kwargs)
     except Exception as err:
       sentry_sdk.capture_exception(str(err))
       client = sentry_sdk.Hub.current.client
